@@ -3,12 +3,12 @@ from __future__ import unicode_literals
 import collections
 import time
 import zipfile
+from io import BytesIO
 
 import pandas as pd
-import pandas.compat as compat
 
 from pandas_datareader.io.util import _read_content
-from pandas_datareader._utils import HTTPError
+from pandas_datareader.compat import HTTPError, str_to_bytes
 
 
 _STRUCTURE = '{http://www.sdmx.org/resources/sdmxml/schemas/v2_1/structure}'
@@ -34,7 +34,7 @@ def read_sdmx(path_or_buf, dtype='float64', dsd=None):
 
     Parameters
     ----------
-    filepath_or_buffer : a valid SDMX-XML string or file-like
+    path_or_buf : a valid SDMX-XML string or file-like
         https://webgate.ec.europa.eu/fpfis/mwikis/sdmx/index.php/Main_Page
     dtype : str
         dtype to coerce values
@@ -65,9 +65,9 @@ def read_sdmx(path_or_buf, dtype='float64', dsd=None):
                 data = _read_zipped_sdmx(result)
                 return read_sdmx(data, dtype=dtype, dsd=dsd)
             except HTTPError:
+                time.sleep(1)
                 continue
 
-            time.sleep(1)
         msg = ('Unable to download zipped data within 60 secs, '
                'please download it manually from: {0}')
         raise ValueError(msg.format(result))
@@ -141,7 +141,8 @@ def _construct_index(keys, dsd=None):
             except KeyError:
                 values[name] = [value]
 
-    midx = pd.MultiIndex.from_arrays([values[name] for name in names], names=names)
+    midx = pd.MultiIndex.from_arrays([values[name] for name in names],
+                                     names=names)
     return midx
 
 
@@ -168,9 +169,11 @@ def _get_child(element, key):
     if len(elements) == 1:
         return elements[0]
     elif len(elements) == 0:
-        raise ValueError("Element {0} contains no {1}".format(element.tag, key))
+        raise ValueError("Element {0} contains "
+                         "no {1}".format(element.tag, key))
     else:
-        raise ValueError("Element {0} contains multiple {1}".format(element.tag, key))
+        raise ValueError("Element {0} contains "
+                         "multiple {1}".format(element.tag, key))
 
 
 _NAME_EN = ".//{0}Name[@{1}lang='en']".format(_COMMON, _XML)
@@ -232,8 +235,8 @@ def _read_zipped_sdmx(path_or_buf):
     """ Unzipp data contains SDMX-XML """
     data = _read_content(path_or_buf)
 
-    zp = compat.BytesIO()
-    zp.write(compat.str_to_bytes(data))
+    zp = BytesIO()
+    zp.write(str_to_bytes(data))
     f = zipfile.ZipFile(zp)
     files = f.namelist()
     assert len(files) == 1
